_**by Edgar Allan Poe**  
(published 1844)_

    

AN EXTRAVAGANZA  
  
    IT was a chilly November afternoon.  I had just consummated an unusually hearty dinner, of which the dyspeptic truffe formed not the least important item, and was sitting alone in the dining-room, with my feet upon the fender, and at my elbow a small table which I had rolled up to the fire, and upon which were some apologies for dessert, with some miscellaneous bottles of wine, spirit and liqueur.  In the morning I had been reading Glover's "Leonidas," Wilkie's "Epigoniad," Lamartine's "Pilgrimage," Barlow's "Columbiad," Tuckermann's "Sicily," and Griswold's "Curiosities" ;  I am willing to confess, therefore, that I now felt a little stupid.  I made effort to arouse myself by aid of frequent Lafitte, and, all failing, I betook myself to a stray newspaper in despair.  Having carefully perused the column of "houses to let," and the column of "dogs lost," and then the two columns of "wives and apprentices runaway," I attacked with great resolution the editorial matter, and, reading it from beginning to end without understanding a syllable, conceived the possibility of its being Chinese, and so re-read it from the end to the beginning, but with no more satisfactory result.  I was about throwing away, in disgust,  
  
    This folio of four pages, happy work  
    Which not even critics criticise,  
  
when I felt my attention somewhat aroused by the paragraph which follows :  
  
    "The avenues to death are numerous and strange.  A London paper mentions the decease of a person from a singular cause.  He was playing at 'puff the dart,' which is played with a long needle inserted in some worsted, and blown at a target through a tin tube.  He placed the needle at the wrong end of the tube, and drawing his breath strongly to puff the dart forward with force, drew the needle into his throat.  It entered the lungs, and in a few days killed him."  
  
    Upon seeing this I fell into a great rage, without exactly knowing why.  "This thing," I exclaimed, "is a contemptible falsehood -- a poor hoax -- the lees of the invention of some pitiable penny-a-liner -- of some wretched concoctor of accidents in Cocaigne.  These fellows, knowing the extravagant gullibility of the age, set their wits to work in the imagination of improbable possibilities -- of odd accidents, as they term them; but to a reflecting intellect (like mine," I added, in parenthesis, putting my forefinger unconsciously to the side of my nose,) "to a contemplative understanding such as I myself possess, it seems evident at once that the marvelous increase of late in these 'odd accidents' is by far the oddest accident of all.  For my own part, I intend to believe nothing henceforward that has anything of the 'singular' about it."  
  
    "Mein Gott, den, vat a vool you bees for dat !" replied one of the most remarkable voices I ever heard.  At first I took it for a rumbling in my ears -- such as a man sometimes experiences when getting very drunk -- but, upon second thought, I considered the sound as more nearly resembling that which proceeds from an empty barrel beaten with a big stick; and, in fact, this I should have concluded it to be, but for the articulation of the syllables and words.  I am by no means naturally nervous, and the very few glasses of Lafitte which I had sipped served to embolden me no little, so that I felt nothing of trepidation, but merely uplifted my eyes with a leisurely movement, and looked carefully around the room for the intruder.  I could not, however, perceive any one at all.  
  
    "Humph !" resumed the voice, as I continued my survey, "you mus pe so dronk as de pig, den, for not zee me as I zit here at your zide."  
  
    Hereupon I bethought me of looking immediately before my nose, and there, sure enough, confronting me at the table sat a personage nondescript, although not altogether indescribable.  His body was a wine-pipe, or a rum-puncheon, or something of that character, and had a truly Falstaffian air.  In its nether extremity were inserted two kegs, which seemed to answer all the purposes of legs.  For arms there dangled from the upper portion of the carcass two tolerably long bottles, with the necks outward for hands. All the head that I saw the monster possessed of was one of those Hessian canteens which resemble a large snuff-box with a hole in the middle of the lid.  This canteen (with a funnel on its top, like a cavalier cap slouched over the eyes) was set on edge upon the puncheon, with the hole toward myself; and through this hole, which seemed puckered up like the mouth of a very precise old maid, the creature was emitting certain rumbling and grumbling noises which he evidently intended for intelligible talk.  
  
    "I zay," said he, "you mos pe dronk as de pig, vor zit dare and not zee me zit ere; and I zay, doo, you mos pe pigger vool as de goose, vor to dispelief vat iz print in de print.  'Tiz de troof -- dat it iz -- eberry vord ob it."  
  
    "Who are you, pray ?" said I, with much dignity, although somewhat puzzled; "how did you get here ?  and what is it you are talking about ?"  
  
    "Az vor ow I com'd ere," replied the figure, "dat iz none of your pizzness; and as vor vat I be talking apout, I be talk apout vat I tink proper; and as vor who I be, vy dat is de very ting I com'd here for to let you zee for yourzelf."  
  
    "You are a drunken vagabond," said I, "and I shall ring the bell and order my footman to kick you into the street."  
  
    "He !  he !  he !" said the fellow, "hu !  hu !  hu !  dat you can't do."  
  
    "Can't do !" said I, "what do you mean ?  -- I can't do what ?"  
  
    "Ring de pell ;" he replied, attempting a grin with his little villainous mouth.  
  
    Upon this I made an effort to get up, in order to put my threat into execution; but the ruffian just reached across the table very deliberately, and hitting me a tap on the forehead with the neck of one of the long bottles, knocked me back into the arm-chair from which I had half arisen.  I was utterly astounded; and, for a moment, was quite at a loss what to do.  In the meantime, he continued his talk.  
  
    "You zee," said he, "it iz te bess vor zit still; and now you shall know who I pe.  Look at me !  zee !  I am te Angel ov te Odd."  
  
    "And odd enough, too," I ventured to reply; "but I was always under the impression that an angel had wings."  
  
    "Te wing  !" he cried, highly incensed, "vat I pe do mit te wing ?  Mein Gott !  do you take me vor a shicken ?"  
  
    "No -- oh no !" I replied, much alarmed, "you are no chicken -- certainly not."  
  
    "Well, den, zit still and pehabe yourself, or I'll rap you again mid me vist.  It iz te shicken ab te wing, und te owl ab te wing, und te imp ab te wing, und te head-teuffel ab te wing.  Te angel ab not te wing, and I am te Angel ov te Odd."  
  
    "And your business with me at present is -- is" --  
  
    "My pizzness !" ejaculated the thing, "vy vat a low bred buppy you mos pe vor to ask a gentleman und an angel apout his pizziness !"  
  
    This language was rather more than I could bear, even from an angel; so, plucking up courage, I seized a salt-cellar which lay within reach, and hurled it at the head of the intruder.  Either he dodged, however, or my aim was inaccurate; for all I accomplished was the demolition of the crystal which protected the dial of the clock upon the mantel-piece.  As for the Angel, he evinced his sense of my assault by giving me two or three hard consecutive raps upon the forehead as before.  These reduced me at once to submission, and I am almost ashamed to confess that either through pain or vexation, there came a few tears into my eyes.  
  
    "Mein Gott !" said the Angel of the Odd, apparently much softened at my distress; "mein Gott, te man is eder ferry dronk or ferry zorry.  You mos not trink it so strong -- you mos put te water in te wine.  Here, trink dis, like a goot veller, und don't gry now -- don't !"  
  
    Hereupon the Angel of the Odd replenished my goblet (which was about a third full of Port) with a colorless fluid that he poured from one of his hand bottles.  I observed that these bottles had labels about their necks, and that these labels were inscribed "Kirschenwasser."    
  
    The considerate kindness of the Angel mollified me in no little measure; and, aided by the water with which he diluted my Port more than once, I at length regained sufficient temper to listen to his very extraordinary discourse.  I cannot pretend to recount all that he told me, but I gleaned from what he said that he was the genius who presided over the contretemps of mankind, and whose business it was to bring about the odd accidents which are continually astonishing the skeptic.  Once or twice, upon my venturing to express my total incredulity in respect to his pretensions, he grew very angry indeed, so that at length I considered it the wiser policy to say nothing at all, and let him have his own way.  He talked on, therefore, at great length, while I merely leaned back in my chair with my eyes shut, and amused myself with munching raisins and filliping the stems about the room.  But, by-and-by, the Angel suddenly construed this behavior of mine into contempt.  He arose in a terrible passion, slouched his funnel down over his eyes, swore a vast oath, uttered a threat of some character which I did not precisely comprehend, and finally made me a low bow and departed, wishing me, in the language of the archbishop in Gil-Blas, "beaucoup de bonheur et un peu plus de bon sens."  
  
    His departure afforded me relief.  The very few glasses of Lafitte that I had sipped had the effect of rendering me drowsy, and I felt inclined to take a nap of some fifteen or twenty minutes, as is my custom after dinner.  At six I had an appointment of consequence, which it was quite indispensable that I should keep.  The policy of insurance for my dwelling house had expired the day before; and, some dispute having arisen, it was agreed that, at six, I should meet the board of directors of the company and settle the terms of a renewal.  Glancing upward at the clock on the mantel-piece, (for I felt too drowsy to take out my watch), I had the pleasure to find that I had still twenty-five minutes to spare. It was half past five; I could easily walk to the insurance office in five minutes; and my usual siestas had never been known to exceed five and twenty.  I felt sufficiently safe, therefore, and composed myself to my slumbers forthwith.  
  
    Having completed them to my satisfaction, I again looked toward the time-piece and was half inclined to believe in the possibility of odd accidents when I found that, instead of my ordinary fifteen or twenty minutes, I had been dozing only three; for it still wanted seven and twenty of the appointed hour.  I betook myself again to my nap, and at length a second time awoke, when, to my utter amazement, it still wanted twenty-seven minutes of six.  I jumped up to examine the clock, and found that it had ceased running.  My watch informed me that it was half past seven; and, of course, having slept two hours, I was too late for my appointment.  "It will make no difference," I said :  "I can call at the office in the morning and apologize; in the meantime what can be the matter with the clock ?" Upon examining it I discovered that one of the raisin stems which I had been filliping about the room during the discourse of the Angel of the Odd, had flown through the fractured crystal, and lodging, singularly enough, in the key-hole, with an end projecting outward, had thus arrested the revolution of the minute hand.  
  
    "Ah !" said I, "I see how it is.  This thing speaks for itself.  A natural accident, such as will happen now and then !"  
  
    I gave the matter no further consideration, and at my usual hour retired to bed.  Here, having placed a candle upon a reading stand at the bed head, and having made an attempt to peruse some pages of the "Omnipresence of the Deity," I unfortunately fell asleep in less than twenty seconds, leaving the light burning as it was.  
  
    My dreams were terrifically disturbed by visions of the Angel of the Odd.  Methought he stood at the foot of the couch, drew aside the curtains, and, in the hollow, detestable tones of a rum puncheon, menaced me with the bitterest vengeance for the contempt with which I had treated him.  He concluded a long harangue by taking off his funnel-cap, inserting the tube into my gullet, and thus deluging me with an ocean of Kirschenwasser, which he poured, in a continuous flood, from one of the long necked bottles that stood him instead of an arm.  My agony was at length insufferable, and I awoke just in time to perceive that a rat had ran off with the lighted candle from the stand, but not in season to prevent his making his escape with it through the hole.  Very soon, a strong suffocating odor assailed my nostrils; the house, I clearly perceived, was on fire. In a few minutes the blaze broke forth with violence, and in an incredibly brief period the entire building was wrapped in flames.  All egress from my chamber, except through a window, was cut off.  The crowd, however, quickly procured and raised a long ladder.  By means of this I was descending rapidly, and in apparent safety, when a huge hog, about whose rotund stomach, and indeed about whose whole air and physiognomy, there was something which reminded me of the Angel of the Odd, -- when this hog, I say, which hitherto had been quietly slumbering in the mud, took it suddenly into his head that his left shoulder needed scratching, and could find no more convenient rubbing-post than that afforded by the foot of the ladder.  In an instant I was precipitated and had the misfortune to fracture my arm.  
  
    This accident, with the loss of my insurance, and with the more serious loss of my hair, the whole of which had been singed off by the fire, predisposed me to serious impressions, so that, finally, I made up my mind to take a wife. There was a rich widow disconsolate for the loss of her seventh husband, and to her wounded spirit I offered the balm of my vows.  She yielded a reluctant consent to my prayers. I knelt at her feet in gratitude and adoration.  She blushed and bowed her luxuriant tresses into close contact with those supplied me, temporarily, by Grandjean. I know not how the entanglement took place, but so it was. I arose with a shining pate, wigless ;  she in disdain and wrath, half buried in alien hair.  Thus ended my hopes of the widow by an accident which could not have been anticipated, to be sure, but which the natural sequence of events had brought about.  
  
    Without despairing, however, I undertook the siege of a less implacable heart.  The fates were again propitious for a brief period; but again a trivial incident interfered.  Meeting my betrothed in an avenue thronged with the élite of the city, I was hastening to greet her with one of my best considered bows, when a small particle of some foreign matter, lodging in the corner of my eye, rendered me, for the moment, completely blind.  Before I could recover my sight, the lady of my love had disappeared -- irreparably affronted at what she chose to consider my premeditated rudeness in passing her by ungreeted.  While I stood bewildered at the suddenness of this accident, (which might have happened, nevertheless, to any one under the sun), and while I still continued incapable of sight, I was accosted by the Angel of the Odd, who proffered me his aid with a civility which I had no reason to expect.  He examined my disordered eye with much gentleness and skill, informed me that I had a drop in it, and (whatever a "drop" was) took it out, and afforded me relief.  
  
    I now considered it high time to die, (since fortune had so determined to persecute me,) and accordingly made my way to the nearest river.  Here, divesting myself of my clothes, (for there is no reason why we cannot die as we were born), I threw myself headlong into the current; the sole witness of my fate being a solitary crow that had been seduced into the eating of brandy-saturated corn, and so had staggered away from his fellows.  No sooner had I entered the water than this bird took it into its head to fly away with the most indispensable portion of my apparel. Postponing, therefore, for the present, my suicidal design, I just slipped my nether extremities into the sleeves of my coat, and betook myself to a pursuit of the felon with all the nimbleness which the case required and its circumstances would admit.  But my evil destiny attended me still. As I ran at full speed, with my nose up in the atmosphere, and intent only upon the purloiner of my property, I suddenly perceived that my feet rested no longer upon terra-firma; the fact is, I had thrown myself over a precipice, and should inevitably have been dashed to pieces but for my good fortune in grasping the end of a long guide-rope, which depended from a passing balloon.  
  
    As soon as I sufficiently recovered my senses to comprehend the terrific predicament in which I stood or rather hung, I exerted all the power of my lungs to make that predicament known to the æronaut overhead.  But for a long time I exerted myself in vain.  Either the fool could not, or the villain would not perceive me.  Meantime the machine rapidly soared, while my strength even more rapidly failed.  I was soon upon the point of resigning myself to my fate, and dropping quietly into the sea, when my spirits were suddenly revived by hearing a hollow voice from above, which seemed to be lazily humming an opera air.  Looking up, I perceived the Angel of the Odd.  He was leaning with his arms folded, over the rim of the car ;  and with a pipe in his mouth, at which he puffed leisurely, seemed to be upon excellent terms with himself and the universe. I was too much exhausted to speak, so I merely regarded him with an imploring air.  
  
    For several minutes, although he looked me full in the face, he said nothing.  At length removing carefully his meerschaum from the right to the left corner of his mouth, he condescended to speak.  
  
    "Who pe you," he asked, "und what der teuffel you pe do dare ?"  
  
    To this piece of impudence, cruelty and affectation, I could reply only by ejaculating the monosyllable "Help !"  
  
    "Elp !" echoed the ruffian -- "not I.  Dare iz te pottle -- elp yourself, und pe tam'd !"  
  
    With these words he let fall a heavy bottle of Kirschenwasser which, dropping precisely upon the crown of my head, caused me to imagine that my brains were entirely knocked out.  Impressed with this idea, I was about to relinquish my hold and give up the ghost with a good grace, when I was arrested by the cry of the Angel, who bade me hold on.  
  
    "Old on !" he said; "don't pe in te urry -- don't. Will you pe take de odder pottle, or ave you pe got zober yet and come to your zenzes ?"  
  
    I made haste, hereupon, to nod my head twice -- once in the negative, meaning thereby that I would prefer not taking the other bottle at present -- and once in the affirmative, intending thus to imply that I was sober and had positively come to my senses.  By these means I somewhat softened the Angel.  
  
    "Und you pelief, ten," he inquired, "at te last ? You pelief, ten, in te possibilty of te odd ?"  
  
    I again nodded my head in assent.  
  
    "Und you ave pelief in me, te Angel of te Odd ?"  
  
    I nodded again.  
  
    "Und you acknowledge tat you pe te blind dronk and te vool ?"  
  
    I nodded once more.  
  
    "Put your right hand into your left hand preeches pocket, ten, in token ov your vull zubmizzion unto te Angel ov te Odd."  
  
    This thing, for very obvious reasons, I found it quite impossible to do.  In the first place, my left arm had been broken in my fall from the ladder, and, therefore, had I let go my hold with the right hand, I must have let go altogether.  In the second place, I could have no breeches until I came across the crow.  I was therefore obliged, much to my regret, to shake my head in the negative -- intending thus to give the Angel to understand that I found it inconvenient, just at that moment, to comply with his very reasonable demand !  No sooner, however, had I ceased shaking my head than --  
  
    "Go to der teuffel, ten !" roared the Angel of the Odd.  
  
    In pronouncing these words, he drew a sharp knife across the guide-rope by which I was suspended, and as we then happened to be precisely over my own house, (which, during my peregrinations, had been handsomely rebuilt,) it so occurred that I tumbled headlong down the ample chimney and alit upon the dining-room hearth.  
  
    Upon coming to my senses, (for the fall had very thoroughly stunned me,) I found it about four o'clock in the morning.  I lay outstretched where I had fallen from the balloon.  My head grovelled in the ashes of an extinguished fire, while my feet reposed upon the wreck of a small table, overthrown, and amid the fragments of a miscellaneous dessert, intermingled with a newspaper, some broken glass and shattered bottles, and an empty jug of the Schiedam Kirschenwasser.  Thus revenged himself the Angel of the Odd.